send\_words package
===================

Submodules
----------

send\_words.cli module
----------------------

.. automodule:: send_words.cli
    :members:
    :undoc-members:
    :show-inheritance:

send\_words.send\_words module
------------------------------

.. automodule:: send_words.send_words
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: send_words
    :members:
    :undoc-members:
    :show-inheritance:
